pub struct JournalXtsCipher { /* private fields */ }Expand description
Cipher used for encrypting and decrypting journal mutations with AES-256-XTS and CTS.
Implementations
Sourceimpl JournalXtsCipher
impl JournalXtsCipher
pub fn new(key: &UnwrappedKey, tweak: u64) -> Self
Sourcepub fn encrypt(&mut self, buffer: &[u8]) -> Vec<u8> ⓘ
pub fn encrypt(&mut self, buffer: &[u8]) -> Vec<u8> ⓘ
Encrypts buffer using AES-256-XTS with ciphertext stealing into a newly allocated vector.
If buffer.len() < 16, it will be zero-padded to 16 bytes first.
Sourcepub fn decrypt(&mut self, buffer: &mut [u8])
pub fn decrypt(&mut self, buffer: &mut [u8])
Decrypts buffer in place using AES-256-XTS with ciphertext stealing.
buffer.len() must be >= 16.
pub fn current_tweak(&self) -> u64
pub fn key_is_new(&self) -> bool